pub struct Canvas { /* private fields */ }Expand description
A Pyxel canvas.
Implementations
Sourceimpl Canvas
impl Canvas
Sourcepub fn tile_height(&self) -> u16
pub fn tile_height(&self) -> u16
Returns the height of the tiles in this canvas in pixels.
Sourcepub fn tile_width(&self) -> u16
pub fn tile_width(&self) -> u16
Returns the width of the tiles in this canvas in pixels.